@@ -1,6 +1,6 @@
 """The Sphinx documentation toolchain."""
 
-__version__ = '7.4.6'
+__version__ = '8.1.1'
 __display_version__ = __version__  # used for command line version
 
 # Keep this file executable as-is in Python 3!
@@ -16,7 +16,10 @@ if 'PYTHONWARNINGS' not in os.environ:
 
     warnings.filterwarnings('default', category=RemovedInNextVersionWarning)
 warnings.filterwarnings(
-    'ignore', 'The frontend.Option class .*', DeprecationWarning, module='docutils.frontend'
+    'ignore',
+    'The frontend.Option class .*',
+    DeprecationWarning,
+    module='docutils.frontend',
 )
 
 #: Version info for better programmatic use.
@@ -27,7 +30,7 @@ warnings.filterwarnings(
 #:
 #: .. versionadded:: 1.2
 #:    Before version 1.2, check the string ``sphinx.__version__``.
-version_info = (7, 4, 6, 'final', 0)
+version_info = (8, 1, 1, 'final', 0)
 
 package_dir = os.path.abspath(os.path.dirname(__file__))
 
